/**
 * Copyright (c) 2008, SnakeYAML
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.yaml.snakeyaml.introspector;

import java.lang.annotation.Annotation;
import java.util.Collections;
import java.util.List;

/**
 * A property that does not map to a real property; this is used when
 * {@link PropertyUtils}.setSkipMissingProperties(boolean) is set to true.
 */
public class MissingProperty extends Property {

  public MissingProperty(String name) {
    super(name, Object.class);
  }

  @Override
  public Class<?>[] getActualTypeArguments() {
    return new Class[0];
  }

  /**
   * Setter does nothing.
   */
  @Override
  public void set(Object object, Object value) throws Exception {}

  @Override
  public Object get(Object object) {
    return object;
  }

  @Override
  public List<Annotation> getAnnotations() {
    return Collections.emptyList();
  }

  @Override
  public <A extends Annotation> A getAnnotation(Class<A> annotationType) {
    return null;
  }

}
